@@ -40,7 +40,7 @@ LearnerClassifCVGlmnet = R6Class("LearnerClassifCVGlmnet",
         exmx                 = p_dbl(default = 250.0, tags = "train"),
         fdev                 = p_dbl(0, 1, default = 1.0e-5, tags = "train"),
         foldid               = p_uty(default = NULL, tags = "train"),
-        gamma                = p_uty(tags = "train"),
+        gamma                = p_uty(tags = "train", depends = quote(relax == TRUE)),
         grouped              = p_lgl(default = TRUE, tags = "train"),
         intercept            = p_lgl(default = TRUE, tags = "train"),
         keep                 = p_lgl(default = FALSE, tags = "train"),
@@ -72,7 +72,6 @@ LearnerClassifCVGlmnet = R6Class("LearnerClassifCVGlmnet",
         type.multinomial     = p_fct(c("ungrouped", "grouped"), tags = "train"),
         upper.limits         = p_uty(tags = "train")
       )
-      ps$add_dep("gamma", "relax", CondEqual$new(TRUE))
 
       super$initialize(
         id = "classif.cv_glmnet",
