@@ -1,8 +1,9 @@
 skip_if_not_installed("nnet")
+skip_on_cran() # numerically instable with ATLAS blas
 
 test_that("autotest", {
-  learner = mlr3::lrn("classif.nnet")
+  learner <- mlr3::lrn("classif.nnet")
   expect_learner(learner)
-  result = run_autotest(learner)
+  result <- run_autotest(learner)
   expect_true(result, info = result$error)
 })
